@@ -22,7 +22,7 @@
 # included in the documentation directory.
 
 # Generate simulated data for testing C++ PReMiuM
-generateSampleDataFile<-function(clusterSummary){
+generateSampleDataFile<-function(clusterSummary,pQuantile=0.05){
 
 	subjectsPerCluster<-clusterSummary$clusterSizes
 	nSubjects<-sum(subjectsPerCluster)
@@ -166,7 +166,7 @@ generateSampleDataFile<-function(clusterSummary){
 		nTrials<-NULL
 	}
 
-	if(outcomeType=='Normal'){
+	if(outcomeType=='Normal'||outcomeType=='Quantile'){
 		sigmaSqY=clusterSummary$sigmaSqY
 	}
 
@@ -214,6 +214,9 @@ generateSampleDataFile<-function(clusterSummary){
 			Y[i]<-sum(runif(nTrials[i])<p)
 		}else if(outcomeType=='Normal'){
 			Y[i]<-rnorm(1,mu+U[i],sqrt(sigmaSqY))
+		}else if(outcomeType=='Quantile'){
+		  Y[i]<-rALD(1,mu+U[i],sqrt(sigmaSqY),p=pQuantile)
+		  #Y[i]<-rnorm(1,mu+U[i],sqrt(sigmaSqY))
 		}else if (outcomeType=='Categorical'){
 			p<-vector()
 			sumMu<-sum(exp(mu))		
@@ -799,6 +802,35 @@ clusSummaryWeibullDiscrete<-function(){
 
 
 
+clusSummaryQuantileNormal<-function(){
+  list(
+    'outcomeType'='Quantile',
+    'covariateType'='Normal',
+    'nCovariates'=1,
+    'nFixedEffects'=0,
+    'sigmaSqY'=1,
+    'missingDataProb'=0,
+    'nClusters'=5,
+    'clusterSizes'=c(600,200,400,300,800),
+    'includeCAR'=FALSE,
+    'TauCAR'=100,
+    'clusterData'=list(
+      list('theta'=-200,
+           'covariateMeans'= 0,
+           'covariateCovariance'=6),
+      list('theta'= 0,
+           'covariateMeans'= 6,
+           'covariateCovariance'=7),
+      list('theta'= 3,
+           'covariateMeans'= -8,
+           'covariateCovariance'=4),
+      list('theta'=40,
+           'covariateMeans'= -3,
+           'covariateCovariance'=10),
+      list('theta'= 150,
+           'covariateMeans'= 5,
+           'covariateCovariance'=17)))
+}
 
 
 
